<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Lasting av liste fra App Store feilet.",
"Authentication error" => "Autentikasjonsfeil",
"Group already exists" => "Gruppen finnes allerede",
"Unable to add group" => "Kan ikke legge til gruppe",
"Could not enable app. " => "Kan ikke aktivere app.",
"Email saved" => "Epost lagret",
"Invalid email" => "Ugyldig epost",
"Unable to delete group" => "Kan ikke slette gruppe",
"Unable to delete user" => "Kan ikke slette bruker",
"Language changed" => "Språk endret",
"Invalid request" => "Ugyldig forespørsel",
"Unable to add user to group %s" => "Kan ikke legge bruker til gruppen %s",
"Unable to remove user from group %s" => "Kan ikke slette bruker fra gruppen %s",
"Disable" => "Slå avBehandle ",
"Enable" => "Slå på",
"Error" => "Feil",
"Saving..." => "Lagrer...",
"deleted" => "slettet",
"undo" => "angre",
"Groups" => "Grupper",
"Group Admin" => "Gruppeadministrator",
"Delete" => "Slett",
"__language_name__" => "__language_name__",
"Security Warning" => "Sikkerhetsadvarsel",
"More" => "Mer",
"Version" => "Versjon",
"Add your App" => "Legg til din App",
"More Apps" => "Flere Apps",
"Select an App" => "Velg en app",
"See application page at apps.owncloud.com" => "Se applikasjonens side på apps.owncloud.org",
"Update" => "Oppdater",
"User Documentation" => "Brukerdokumentasjon",
"Administrator Documentation" => "Administratordokumentasjon",
"Commercial Support" => "Kommersiell støtte",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Du har brukt <strong>%s</strong> av tilgjengelig <strong>%s</strong>",
"Get the apps to sync your files" => "Få dine apps til å synkronisere dine filer",
"Password" => "Passord",
"Your password was changed" => "Passord har blitt endret",
"Unable to change your password" => "Kunne ikke endre passordet ditt",
"Current password" => "Nåværende passord",
"New password" => "Nytt passord",
"Change password" => "Endre passord",
"Email" => "E-post",
"Your email address" => "Din e-postadresse",
"Fill in an email address to enable password recovery" => "Oppi epostadressen du vil tilbakestille passordet for",
"Language" => "Språk",
"Help translate" => "Bidra til oversettelsen",
"WebDAV" => "WebDAV",
"Create" => "Opprett",
"Other" => "Annet"
);
